# Variables

variable "instance_size" {
  description = "Size of instance to create"
  default = "t2.micro"
  validation {
          condition     = ( 
            var.instance_size == "t2.micro"  ||
            var.instance_size == "t3.medium"  ||
            var.instance_size == "m5.large"   ||
            var.instance_size == "c5.large"   ||
            var.instance_size == "c5a.large"  ||
            var.instance_size == "m5.2xlarge" ||
            var.instance_size == "c5.2xlarge" ||
            var.instance_size == "m5.4xlarge" ||
            var.instance_size == "c5.4xlarge" ||
            var.instance_size == "m6i.large"
          )
          error_message = "Input instance_size must be set to an approved vm instance type."
      }
}

variable "vpc_cidr" {
  description = "CIDR of VPC Subnet"
  default = "10.0.0.0/16"
}

variable "public_cidr" {
  description = "CIDR of Public Subnet"
  default = "10.0.1.0/24"
}

variable "name_prefix" {
  description = "The prefix for all your resources"
  default     = "demostar"
  type        = string
}

variable "name_suffix" {
  description = "The suffix for all your resources, suggest generating a unique value for each deployment"
  type        = string
}

variable "disk_size" {
  description = "Size of instance disk in Gigabytes"
  default = 10
}

variable "SSH_PUBLIC_KEY" {
  description = "SSH Public Key to add to .authorized_keys for the 'ubuntu' user"
  default = ""
}

